# 🧪 Examples

This section contains a gallery of example notebooks demonstrating the features and capabilities of `cherab-imas`.
Each notebook is designed to showcase specific functionalities and provide practical insights into using the library effectively.

## Plasma

```{eval-rst}
.. nbgallery::
    :name: plasma-gallery
    :glob:
    :reversed:

    notebooks/plasma/*
```

## Observer

```{eval-rst}
.. nbgallery::
    :name: observer-gallery
    :glob:
    :reversed:

    notebooks/observer/*
```

## Miscellaneous

```{eval-rst}
.. nbgallery::
    :name: misc-gallery
    :glob:
    :reversed:

    notebooks/misc/*
```
